# CommonSense QA1

Sample generated by `lime init dataset --simple`

#### meta
- max_tokens: 15

#### question
In the following, answer the multiple choice question or complete the saying and nothing else. Use commonsense and traditional folk wisdom to answer the question.
|EVAL-ENDCHAR|

## Q-1
#### meta
#### answer
C) The worm<EVAL-ENDCHAR>

#### question
Q: What did the early bird get?
A) The bill
B) The beer
C) The worm
<EVAL-ENDCHAR>

## Q-2
#### meta
#### question
Q: Complete the following sentence.

How much wood
could a woodchuck chuck
if a |EVAL-ENDCHAR|

#### answer
woodchuck
could chuck
wood|EVAL-ENDCHAR|